@@ -1,5 +1,6 @@
-# -*- coding: utf-8
-from __future__ import unicode_literals, absolute_import
+#!/usr/bin/env python
+# -*- coding: utf8 -*-
+from __future__ import absolute_import, division, generators, nested_scopes, print_function, unicode_literals, with_statement
 
 from xlsxhelper import get_workbook
 from xlsxhelper import get_worksheet
@@ -8,8 +9,9 @@ import datetime
 import codecs
 import click
 
-header = """# -*- coding: utf-8
-from __future__ import unicode_literals, absolute_import
+header = """#!/usr/bin/env python
+# -*- coding: utf8 -*-
+from __future__ import absolute_import, division, generators, nested_scopes, print_function, unicode_literals, with_statement
 from bizerror.base import BizErrorBase
 from bizerror.base import set_error_info
 
